@@ -1,6 +1,6 @@
 import math
 import numbers
-from adsb_tools.utils import requests_utils
+from adsb_tools.utils import requests_utils, spatial_utils
 # from pprint import pprint
 
 EARTH_RADIUS_KM = 6371.0
@@ -129,13 +129,13 @@ class Aircraft:
                 aircraft_lat = new_aircraft['lat']
                 aircraft_lon = new_aircraft['lon']
 
-                distances = Aircraft.calculate_distances(
+                distances = spacial_utils.calculate_distances(
                     self.base_latitude, self.base_longitude, aircraft_lat, aircraft_lon
                 )
-                degrees = Aircraft.get_degrees(
+                degrees = spacial_utils.get_degrees(
                     self.base_latitude, self.base_longitude, aircraft_lat, aircraft_lon
                 )
-                direction = Aircraft.get_cardinal_direction(degrees)
+                direction = spacial_utils.get_cardinal_direction(degrees)
 
                 new_aircraft['distance'] = {
                     **distances,
@@ -147,7 +147,7 @@ class Aircraft:
                 if ('track' in aircraft and isinstance(aircraft['track'], numbers.Number)):
                     movement = {
                         'track': aircraft['track'],
-                        'direction': Aircraft.get_cardinal_direction(aircraft['track'])
+                        'direction': spacial_utils.get_cardinal_direction(aircraft['track'])
                     }
                 new_aircraft['movement'] = movement
 
@@ -256,63 +256,6 @@ class Aircraft:
             }
 
         return image
-
-    @staticmethod
-    def calculate_distances(lat1, lon1, lat2, lon2):
-        """
-        Calculates the great-circle distance between two points on the Earth's surface
-        using the Haversine formula.
-
-        Args:
-            lat1 (float): Latitude of the first point in degrees
-            lon1 (float): Longitude of the first point in degrees
-            lat2 (float): Latitude of the second point in degrees
-            lon2 (float): Longitude of the second point in degrees
-
-        Returns:
-            float: Distance between the two points in kilometers
-        """
-
-        # Convert coordinates to radians
-        lat1, lon1, lat2, lon2 = map(math.radians, [lat1, lon1, lat2, lon2])
-
-        # Haversine formula
-        dlat = lat2 - lat1
-        dlon = lon2 - lon1
-        square_half_chord = math.sin(dlat/2)**2 + math.cos(lat1) * math.cos(lat2) * math.sin(dlon/2)**2
-        angular_distance = 2 * math.atan2(math.sqrt(square_half_chord), math.sqrt(1-square_half_chord))
-
-        # return distance
-        return {
-            "ft": RADIUS_EARTH_FEET * angular_distance,
-            "mi": RADIUS_EARTH_MILES * angular_distance,
-            "km": RADIUS_EARTH_KM * angular_distance,
-            "nm": RADIUS_EARTH_NM * angular_distance,
-            "m": RADIUS_EARTH_METERS * angular_distance
-        }
-
-
-    @staticmethod
-    def get_degrees(base_lat, base_lon, dest_lat, dest_lon):
-        """Calculate the degrees from one coordinate to another."""
-        # Calculate the difference between the latitudes and longitudes
-        lat_diff = dest_lat - base_lat
-        lon_diff = dest_lon - base_lon
-
-        # Calculate the angle between the two points in radians
-        angle = math.atan2(lon_diff, lat_diff)
-
-        # Convert the angle from radians to degrees
-        return math.degrees(angle)
-
-
-    @staticmethod
-    def get_cardinal_direction(degrees):
-        """Calculate the direction from one coordinate to another."""
-        # Convert the angle to a compass direction
-        directions = ['N', 'NE', 'E', 'SE', 'S', 'SW', 'W', 'NW']
-        idx = round(degrees / (360.0 / len(directions))) % len(directions)
-        return directions[idx]
     
 
     @staticmethod
